@@ -58,7 +58,7 @@ struct _GPAPrinterSelectorClass {
 	GPAWidgetClass widget_class;
 };
 
-GtkType     gpa_printer_selector_get_type (void);
+GType       gpa_printer_selector_get_type (void);
 
 GtkWidget * gpa_printer_selector_new (GnomePrintConfig *gpc);
 
